SRC_PATH = [
    "/Users/osso/src/invenio",
    "/Users/osso/src/inspire",
]

USE_CONSOLE = False
